<?php

App::uses('BaseMigrationModelUtil', 'EvMigrationUtil.Lib');
App::uses('MigrationUtil', 'EvMigrationUtil.Lib');

class SiteSettingMigrationModelUtil extends BaseMigrationModelUtil {

/**
 * Builds a Site Setting. Will also add the category if it doesn't exist. Uses the humanized version of the slug as the name.
 * expects an array with setting and category keys
 *
 * @param string $slug The setting slug
 * @param string $categorySlug The category slug to place this setting in. The category will be created if it doesn't exist
 * @param string $type The field type
 * @param array $options Options to override the default options. Options include name, valueOptions, value, sequence, preventEdit, categoryName, categorySequence
 *
 * @return int|bool The site setting id or false on fail
 */
	public function createOnceWithCategory($slug, $categorySlug, $type, $options = []) {
		$options = array_merge([
			'name' => InflectorExt::humanize($slug),
			'valueOptions' => '',
			'value' => null,
			'sequence' => 0,
			'preventEdit' => false,
			'categoryName' => InflectorExt::humanize($categorySlug),
			'categorySequence' => 0,
		], $options);

		$categoryUtil = MigrationUtil::init('EvSiteSettings.SiteSettingCategory');
		$categoryId = $categoryUtil->createCategoryOnce($categorySlug, $options['categoryName'], $options['categorySequence'], $options['preventEdit']);

		if (empty($categoryId)) {
			return false;
		}

		return $this->createOnce([
			$this->Model->alias . '.array_slug' => $slug,
			$this->Model->alias . '.site_setting_category_id' => $categoryId,
		], [
			'SiteSetting' => [
				'array_slug' => $slug,
				'name' => $options['name'],
				'type' => $type,
				'options' => $options['valueOptions'],
				'value' => $options['value'],
				'sequence' => $options['sequence'],
				'site_setting_category_id' => $categoryId,
				'prevent_edit' => $options['preventEdit']
			]
		]);
	}

/**
 * Deletes based on a slug
 *
 * @param string $slug         The setting slug
 * @param string $categorySlug The category slug
 * @return void
 */
	public function deleteWithSlug($slug, $categorySlug) {
		$categoryId = $this->Model->SiteSettingCategory->field('id', ['array_slug' => $categorySlug]);
		if (!empty($categoryId)) {
			$this->deleteAll([
				$this->Model->alias . '.array_slug' => $slug,
				$this->Model->alias . '.site_setting_category_id' => $categoryId
			]);
		}
	}

}
